@@ -341,6 +341,9 @@ type CheClusterSpecServer struct {
 	// The Che server route custom settings.
 	// +optional
 	CheServerRoute RouteCustomSettings `json:"cheServerRoute,omitempty"`
+	// Default plug-ins applied to Devworkspaces.
+	// +optional
+	WorkspacesDefaultPlugins []WorkspacesDefaultPlugins `json:"workspacesDefaultPlugins,omitempty"`
 }
 
 // +k8s:openapi-gen=true
@@ -546,6 +549,13 @@ type ResourcesCustomSettings struct {
 	Limits Resources `json:"limits,omitempty"`
 }
 
+type WorkspacesDefaultPlugins struct {
+	// The editor id to specify default plug-ins for.
+	Editor string `json:"editor,omitempty"`
+	// Default plug-in uris for the specified editor.
+	Plugins []string `json:"plugins,omitempty"`
+}
+
 // List of resources
 type Resources struct {
 	// Memory, in bytes. (500Gi = 500GiB = 500 * 1024 * 1024 * 1024)
