@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -66,14 +66,3 @@ func GetProxyConfiguration(deployContext *deploy.DeployContext) (*deploy.Proxy,
 	}
 	return cheClusterProxyConf, nil
 }
-
-func (r *CheClusterReconciler) putOpenShiftCertsIntoConfigMap(deployContext *deploy.DeployContext) (bool, error) {
-	if deployContext.CheCluster.Spec.Server.ServerTrustStoreConfigMapName == "" {
-		deployContext.CheCluster.Spec.Server.ServerTrustStoreConfigMapName = deploy.DefaultServerTrustStoreConfigMapName()
-		if err := deploy.UpdateCheCRSpec(deployContext, "truststore configmap", deploy.DefaultServerTrustStoreConfigMapName()); err != nil {
-			return false, err
-		}
-	}
-
-	return SyncTrustStoreConfigMapToCluster(deployContext)
-}
