@@ -38,13 +38,27 @@ import (
 )
 
 func RestoreChe(rctx *RestoreContext, dataDir string) (bool, error) {
-	// Delete existing Che resources if any
-	if !rctx.state.oldCheCleaned {
+	// Request deletion of existing Che resources if any
+	if !rctx.state.oldCheDeletionRequested {
 		done, err := cleanPreviousInstallation(rctx, dataDir)
 		if err != nil || !done {
 			return done, err
 		}
 
+		rctx.state.oldCheDeletionRequested = true
+		if err := rctx.UpdateRestoreStatus(); err != nil {
+			return false, err
+		}
+	}
+
+	// Waiting for finalizers of existing Che if any
+	if !rctx.state.oldCheCleaned {
+		done, err := waitPreviousInstallationDeleted(rctx)
+		if err != nil || !done {
+			logrus.Info("Restore: Waiting for existing Che to be deleted")
+			return done, err
+		}
+
 		rctx.state.oldCheCleaned = true
 		if err := rctx.UpdateRestoreStatus(); err != nil {
 			return false, err
@@ -97,10 +111,12 @@ func RestoreChe(rctx *RestoreContext, dataDir string) (bool, error) {
 			return done, err
 		}
 
-		// After Keycloak's database restoring, it is required to restart Keycloak to invalidate its cache.
-		done, err = deleteKeycloakPod(rctx)
-		if err != nil || !done {
-			return done, err
+		if !rctx.cheCR.Spec.DevWorkspace.Enable {
+			// After Keycloak's database restoring, it is required to restart Keycloak to invalidate its cache.
+			done, err = deleteKeycloakPod(rctx)
+			if err != nil || !done {
+				return done, err
+			}
 		}
 
 		rctx.state.cheDatabaseRestored = true
@@ -123,6 +139,9 @@ func cleanPreviousInstallation(rctx *RestoreContext, dataDir string) (bool, erro
 		rctx.cheCR = cheCR
 	}
 
+	// Drop databases, if any, to handle case of different Postgres version (otherwise clean Che will fail to start due to old data in volume)
+	dropDatabases(rctx)
+
 	// Delete Che CR to stop operator from dealing with current installation
 	actualCheCR, cheCRCount, err := util.FindCheClusterCRInNamespace(rctx.r.cachingClient, rctx.namespace)
 	if cheCRCount == -1 {
@@ -206,6 +225,19 @@ func cleanPreviousInstallation(rctx *RestoreContext, dataDir string) (bool, erro
 	return true, nil
 }
 
+func waitPreviousInstallationDeleted(rctx *RestoreContext) (bool, error) {
+	_, cheCRCount, err := util.FindCheClusterCRInNamespace(rctx.r.cachingClient, rctx.namespace)
+	if cheCRCount == -1 {
+		// An error occurred while retreiving CheCluster CR
+		return false, err
+	} else if cheCRCount > 0 {
+		// Wait more for finalizers
+		return false, nil
+	}
+	// Che CR is deleted
+	return true, nil
+}
+
 func deleteKeycloakPod(rctx *RestoreContext) (bool, error) {
 	k8sClient := util.GetK8Client()
 	keycloakPodName, err := k8sClient.GetDeploymentPod(deploy.IdentityProviderName, rctx.namespace)
@@ -425,6 +457,36 @@ func readBackupMetadata(rctx *RestoreContext, dataDir string) (*checlusterbackup
 	return backupMetadata, true, nil
 }
 
+// dropDatabases deletes Che related databases from Postgres, if any
+func dropDatabases(rctx *RestoreContext) {
+	if rctx.cheCR.Spec.Database.ExternalDb {
+		// Skip this step as there is an external server to connect to
+		return
+	}
+
+	databasesToDrop := []string{
+		rctx.cheCR.Spec.Database.ChePostgresDb,
+		"keycloak",
+	}
+
+	k8sClient := util.GetK8Client()
+	postgresPodName, err := k8sClient.GetDeploymentPod(deploy.PostgresName, rctx.namespace)
+	if err != nil {
+		// Postgres pod not found, probably it doesn't exist
+		return
+	}
+
+	for _, dbName := range databasesToDrop {
+		execReason := fmt.Sprintf("dropping %s database", dbName)
+		dropDatabaseCommand := fmt.Sprintf("psql -c \"DROP DATABASE IF EXISTS %s;\"", dbName)
+		if output, err := k8sClient.DoExecIntoPod(rctx.namespace, postgresPodName, dropDatabaseCommand, execReason); err != nil {
+			if output != "" {
+				logrus.Error(output)
+			}
+		}
+	}
+}
+
 func restoreDatabase(rctx *RestoreContext, dataDir string) (bool, error) {
 	if rctx.cheCR.Spec.Database.ExternalDb {
 		// Skip database restore as there is an external server to connect to
