@@ -1,3 +1,15 @@
+//
+// Copyright (c) 2019-2021 Red Hat, Inc.
+// This program and the accompanying materials are made
+// available under the terms of the Eclipse Public License 2.0
+// which is available at https://www.eclipse.org/legal/epl-2.0/
+//
+// SPDX-License-Identifier: EPL-2.0
+//
+// Contributors:
+//   Red Hat, Inc. - initial API and implementation
+//
+
 package defaults
 
 import (
@@ -5,6 +17,7 @@ import (
 	"runtime"
 
 	"github.com/eclipse-che/che-operator/api/v2alpha1"
+	"github.com/eclipse-che/che-operator/pkg/deploy"
 	ctrl "sigs.k8s.io/controller-runtime"
 )
 
@@ -61,7 +74,7 @@ func AddStandardLabelsForComponent(cluster *v2alpha1.CheCluster, component strin
 
 func AddStandardLabelsFromNames(appName string, component string, labels map[string]string) map[string]string {
 	labels["app.kubernetes.io/name"] = appName
-	labels["app.kubernetes.io/part-of"] = appName
+	labels["app.kubernetes.io/part-of"] = deploy.CheEclipseOrg
 	labels["app.kubernetes.io/component"] = component
 	return labels
 }
