@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2012-2019 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -313,9 +313,9 @@ func TestMountSecret(t *testing.T) {
 					},
 				},
 				ClusterAPI: ClusterAPI{
-					Client:          cli,
-					NonCachedClient: cli,
-					Scheme:          scheme.Scheme,
+					Client:           cli,
+					NonCachingClient: cli,
+					Scheme:           scheme.Scheme,
 				},
 			}
 
@@ -591,9 +591,9 @@ func TestMountConfigMaps(t *testing.T) {
 					},
 				},
 				ClusterAPI: ClusterAPI{
-					Client:          cli,
-					NonCachedClient: cli,
-					Scheme:          scheme.Scheme,
+					Client:           cli,
+					NonCachingClient: cli,
+					Scheme:           scheme.Scheme,
 				},
 			}
 
@@ -620,9 +620,9 @@ func TestSyncEnvVarDeploymentToCluster(t *testing.T) {
 			},
 		},
 		ClusterAPI: ClusterAPI{
-			Client:          cli,
-			NonCachedClient: cli,
-			Scheme:          scheme.Scheme,
+			Client:           cli,
+			NonCachingClient: cli,
+			Scheme:           scheme.Scheme,
 		},
 		Proxy: &Proxy{},
 	}
