@@ -12,12 +12,11 @@
 package server
 
 import (
-	"errors"
 	"strconv"
 	"strings"
 
 	"github.com/eclipse-che/che-operator/pkg/deploy"
-	identity_provider "github.com/eclipse-che/che-operator/pkg/deploy/identity-provider"
+	identityprovider "github.com/eclipse-che/che-operator/pkg/deploy/identity-provider"
 	"github.com/eclipse-che/che-operator/pkg/deploy/postgres"
 	"github.com/eclipse-che/che-operator/pkg/deploy/tls"
 
@@ -29,18 +28,18 @@ import (
 	"k8s.io/apimachinery/pkg/util/intstr"
 )
 
-func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
-	selfSignedCASecretExists, err := tls.IsSelfSignedCASecretExists(s.deployContext)
+func (s CheServerReconciler) getDeploymentSpec(ctx *deploy.DeployContext) (*appsv1.Deployment, error) {
+	selfSignedCASecretExists, err := tls.IsSelfSignedCASecretExists(ctx)
 	if err != nil {
 		return nil, err
 	}
 
-	cmResourceVersions := GetCheConfigMapVersion(s.deployContext)
-	cmResourceVersions += "," + tls.GetAdditionalCACertsConfigMapVersion(s.deployContext)
+	cmResourceVersions := GetCheConfigMapVersion(ctx)
+	cmResourceVersions += "," + tls.GetAdditionalCACertsConfigMapVersion(ctx)
 
 	terminationGracePeriodSeconds := int64(30)
-	cheFlavor := deploy.DefaultCheFlavor(s.deployContext.CheCluster)
-	labels, labelSelector := deploy.GetLabelsAndSelector(s.deployContext.CheCluster, cheFlavor)
+	cheFlavor := deploy.DefaultCheFlavor(ctx.CheCluster)
+	labels, labelSelector := deploy.GetLabelsAndSelector(ctx.CheCluster, cheFlavor)
 	optionalEnv := true
 	selfSignedCertEnv := corev1.EnvVar{
 		Name:  "CHE_SELF__SIGNED__CERT",
@@ -82,7 +81,7 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 			},
 		}
 	}
-	if s.deployContext.CheCluster.Spec.Server.GitSelfSignedCert {
+	if ctx.CheCluster.Spec.Server.GitSelfSignedCert {
 		gitSelfSignedCertEnv = corev1.EnvVar{
 			Name: "CHE_GIT_SELF__SIGNED__CERT",
 			ValueFrom: &corev1.EnvVarSource{
@@ -114,7 +113,7 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 	cheEnv = append(cheEnv, gitSelfSignedCertEnv)
 	cheEnv = append(cheEnv, gitSelfSignedCertHostEnv)
 
-	identityProviderSecret := s.deployContext.CheCluster.Spec.Auth.IdentityProviderSecret
+	identityProviderSecret := ctx.CheCluster.Spec.Auth.IdentityProviderSecret
 	if len(identityProviderSecret) > 0 {
 		cheEnv = append(cheEnv, corev1.EnvVar{
 			Name: "CHE_KEYCLOAK_ADMIN__PASSWORD",
@@ -141,11 +140,11 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 	} else {
 		cheEnv = append(cheEnv, corev1.EnvVar{
 			Name:  "CHE_KEYCLOAK_ADMIN__PASSWORD",
-			Value: s.deployContext.CheCluster.Spec.Auth.IdentityProviderPassword,
+			Value: ctx.CheCluster.Spec.Auth.IdentityProviderPassword,
 		},
 			corev1.EnvVar{
 				Name:  "CHE_KEYCLOAK_ADMIN__USERNAME",
-				Value: s.deployContext.CheCluster.Spec.Auth.IdentityProviderAdminUserName,
+				Value: ctx.CheCluster.Spec.Auth.IdentityProviderAdminUserName,
 			})
 	}
 
@@ -162,15 +161,15 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 					FieldPath:  "metadata.namespace"}},
 		})
 
-	if util.IsOpenShift && s.deployContext.CheCluster.IsNativeUserModeEnabled() {
+	if ctx.CheCluster.IsNativeUserModeEnabled() {
 		cheEnv = append(cheEnv, corev1.EnvVar{
 			Name:  "CHE_AUTH_NATIVEUSER",
 			Value: "true",
 		})
 	}
 
-	cheImageAndTag := GetFullCheServerImageLink(s.deployContext.CheCluster)
-	pullPolicy := corev1.PullPolicy(util.GetValue(string(s.deployContext.CheCluster.Spec.Server.CheImagePullPolicy), deploy.DefaultPullPolicyFromDockerImage(cheImageAndTag)))
+	cheImageAndTag := GetFullCheServerImageLink(ctx.CheCluster)
+	pullPolicy := corev1.PullPolicy(util.GetValue(string(ctx.CheCluster.Spec.Server.CheImagePullPolicy), deploy.DefaultPullPolicyFromDockerImage(cheImageAndTag)))
 
 	deployment := &appsv1.Deployment{
 		TypeMeta: metav1.TypeMeta{
@@ -179,7 +178,7 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 		},
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      cheFlavor,
-			Namespace: s.deployContext.CheCluster.Namespace,
+			Namespace: ctx.CheCluster.Namespace,
 			Labels:    labels,
 		},
 		Spec: appsv1.DeploymentSpec{
@@ -222,18 +221,18 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 							Resources: corev1.ResourceRequirements{
 								Requests: corev1.ResourceList{
 									corev1.ResourceMemory: util.GetResourceQuantity(
-										s.deployContext.CheCluster.Spec.Server.ServerMemoryRequest,
+										ctx.CheCluster.Spec.Server.ServerMemoryRequest,
 										deploy.DefaultServerMemoryRequest),
 									corev1.ResourceCPU: util.GetResourceQuantity(
-										s.deployContext.CheCluster.Spec.Server.ServerCpuRequest,
+										ctx.CheCluster.Spec.Server.ServerCpuRequest,
 										deploy.DefaultServerCpuRequest),
 								},
 								Limits: corev1.ResourceList{
 									corev1.ResourceMemory: util.GetResourceQuantity(
-										s.deployContext.CheCluster.Spec.Server.ServerMemoryLimit,
+										ctx.CheCluster.Spec.Server.ServerMemoryLimit,
 										deploy.DefaultServerMemoryLimit),
 									corev1.ResourceCPU: util.GetResourceQuantity(
-										s.deployContext.CheCluster.Spec.Server.ServerCpuLimit,
+										ctx.CheCluster.Spec.Server.ServerCpuLimit,
 										deploy.DefaultServerCpuLimit),
 								},
 							},
@@ -262,23 +261,23 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 		},
 	}
 
-	err = MountBitBucketOAuthConfig(s.deployContext, deployment)
+	err = MountBitBucketOAuthConfig(ctx, deployment)
 	if err != nil {
 		return nil, err
 	}
 
-	err = MountGitHubOAuthConfig(s.deployContext, deployment)
+	err = MountGitHubOAuthConfig(ctx, deployment)
 	if err != nil {
 		return nil, err
 	}
 
-	err = MountGitLabOAuthConfig(s.deployContext, deployment)
+	err = MountGitLabOAuthConfig(ctx, deployment)
 	if err != nil {
 		return nil, err
 	}
 
 	container := &deployment.Spec.Template.Spec.Containers[0]
-	chePostgresSecret := s.deployContext.CheCluster.Spec.Database.ChePostgresSecret
+	chePostgresSecret := ctx.CheCluster.Spec.Database.ChePostgresSecret
 	if len(chePostgresSecret) > 0 {
 		container.Env = append(container.Env,
 			corev1.EnvVar{
@@ -305,7 +304,7 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 	}
 
 	// configure probes if debug isn't set
-	cheDebug := util.GetValue(s.deployContext.CheCluster.Spec.Server.CheDebug, deploy.DefaultCheDebug)
+	cheDebug := util.GetValue(ctx.CheCluster.Spec.Server.CheDebug, deploy.DefaultCheDebug)
 	if cheDebug != "true" {
 		container.ReadinessProbe = &corev1.Probe{
 			Handler: corev1.Handler{
@@ -347,11 +346,11 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 	}
 
 	if !util.IsOpenShift {
-		runAsUser, err := strconv.ParseInt(util.GetValue(s.deployContext.CheCluster.Spec.K8s.SecurityContextRunAsUser, deploy.DefaultSecurityContextRunAsUser), 10, 64)
+		runAsUser, err := strconv.ParseInt(util.GetValue(ctx.CheCluster.Spec.K8s.SecurityContextRunAsUser, deploy.DefaultSecurityContextRunAsUser), 10, 64)
 		if err != nil {
 			return nil, err
 		}
-		fsGroup, err := strconv.ParseInt(util.GetValue(s.deployContext.CheCluster.Spec.K8s.SecurityContextFsGroup, deploy.DefaultSecurityContextFsGroup), 10, 64)
+		fsGroup, err := strconv.ParseInt(util.GetValue(ctx.CheCluster.Spec.K8s.SecurityContextFsGroup, deploy.DefaultSecurityContextFsGroup), 10, 64)
 		if err != nil {
 			return nil, err
 		}
@@ -361,17 +360,17 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 		}
 	}
 
-	if deploy.IsComponentReadinessInitContainersConfigured(s.deployContext.CheCluster) {
-		if !s.deployContext.CheCluster.Spec.Database.ExternalDb {
-			waitForPostgresInitContainer, err := postgres.GetWaitForPostgresInitContainer(s.deployContext)
+	if deploy.IsComponentReadinessInitContainersConfigured(ctx.CheCluster) {
+		if !ctx.CheCluster.Spec.Database.ExternalDb {
+			waitForPostgresInitContainer, err := postgres.GetWaitForPostgresInitContainer(ctx)
 			if err != nil {
 				return nil, err
 			}
 			deployment.Spec.Template.Spec.InitContainers = append(deployment.Spec.Template.Spec.InitContainers, *waitForPostgresInitContainer)
 		}
 
-		if !s.deployContext.CheCluster.Spec.Auth.ExternalIdentityProvider {
-			waitForKeycloakInitContainer, err := identity_provider.GetWaitForKeycloakInitContainer(s.deployContext)
+		if !ctx.CheCluster.Spec.Auth.ExternalIdentityProvider {
+			waitForKeycloakInitContainer, err := identityprovider.GetWaitForKeycloakInitContainer(ctx)
 			if err != nil {
 				return nil, err
 			}
@@ -404,115 +403,58 @@ func GetFullCheServerImageLink(checluster *orgv1.CheCluster) string {
 	return imageParts[0] + ":" + checluster.Spec.Server.CheImageTag
 }
 
-func MountBitBucketOAuthConfig(deployContext *deploy.DeployContext, deployment *appsv1.Deployment) error {
-	secrets, err := deploy.GetSecrets(deployContext, map[string]string{
-		deploy.KubernetesPartOfLabelKey:    deploy.CheEclipseOrg,
-		deploy.KubernetesComponentLabelKey: deploy.OAuthScmConfiguration,
-	}, map[string]string{
-		deploy.CheEclipseOrgOAuthScmServer: "bitbucket",
-	})
-
-	if err != nil {
+func MountBitBucketOAuthConfig(ctx *deploy.DeployContext, deployment *appsv1.Deployment) error {
+	secret, err := getOAuthConfig(ctx, "bitbucket")
+	if secret == nil {
 		return err
-	} else if len(secrets) > 1 {
-		return errors.New("More than 1 BitBucket OAuth configuration secrets found")
-	} else if len(secrets) == 1 {
-		mountSecret(deployment, &secrets[0], deploy.BitBucketOAuthConfigMountPath)
-		mountEnv(deployment, []corev1.EnvVar{
-			{
-				Name:  "CHE_OAUTH1_BITBUCKET_CONSUMERKEYPATH",
-				Value: deploy.BitBucketOAuthConfigMountPath + "/" + deploy.BitBucketOAuthConfigConsumerKeyFileName,
-			}, {
-				Name:  "CHE_OAUTH1_BITBUCKET_PRIVATEKEYPATH",
-				Value: deploy.BitBucketOAuthConfigMountPath + "/" + deploy.BitBucketOAuthConfigPrivateKeyFileName,
-			},
-		})
-
-		endpoint := secrets[0].Annotations[deploy.CheEclipseOrgScmServerEndpoint]
-		if endpoint != "" {
-			mountEnv(deployment, []corev1.EnvVar{{
-				Name:  "CHE_OAUTH1_BITBUCKET_ENDPOINT",
-				Value: endpoint,
-			}})
-		}
 	}
 
+	mountVolumes(deployment, secret, deploy.BitBucketOAuthConfigMountPath)
+	mountEnv(deployment, "CHE_OAUTH1_BITBUCKET_CONSUMERKEYPATH", deploy.BitBucketOAuthConfigMountPath+"/"+deploy.BitBucketOAuthConfigConsumerKeyFileName)
+	mountEnv(deployment, "CHE_OAUTH1_BITBUCKET_PRIVATEKEYPATH", deploy.BitBucketOAuthConfigMountPath+"/"+deploy.BitBucketOAuthConfigPrivateKeyFileName)
+
+	oauthEndpoint := secret.Annotations[deploy.CheEclipseOrgScmServerEndpoint]
+	if oauthEndpoint != "" {
+		mountEnv(deployment, "CHE_OAUTH1_BITBUCKET_ENDPOINT", oauthEndpoint)
+	}
 	return nil
 }
 
-func MountGitHubOAuthConfig(deployContext *deploy.DeployContext, deployment *appsv1.Deployment) error {
-	secrets, err := deploy.GetSecrets(deployContext, map[string]string{
-		deploy.KubernetesPartOfLabelKey:    deploy.CheEclipseOrg,
-		deploy.KubernetesComponentLabelKey: deploy.OAuthScmConfiguration,
-	}, map[string]string{
-		deploy.CheEclipseOrgOAuthScmServer: "github",
-	})
-
-	if err != nil {
+func MountGitHubOAuthConfig(ctx *deploy.DeployContext, deployment *appsv1.Deployment) error {
+	secret, err := getOAuthConfig(ctx, "github")
+	if secret == nil {
 		return err
-	} else if len(secrets) > 1 {
-		return errors.New("More than 1 GitHub OAuth configuration secrets found")
-	} else if len(secrets) == 1 {
-		mountSecret(deployment, &secrets[0], deploy.GitHubOAuthConfigMountPath)
-		mountEnv(deployment, []corev1.EnvVar{
-			{
-				Name:  "CHE_OAUTH2_GITHUB_CLIENTID__FILEPATH",
-				Value: deploy.GitHubOAuthConfigMountPath + "/" + deploy.GitHubOAuthConfigClientIdFileName,
-			}, {
-				Name:  "CHE_OAUTH2_GITHUB_CLIENTSECRET__FILEPATH",
-				Value: deploy.GitHubOAuthConfigMountPath + "/" + deploy.GitHubOAuthConfigClientSecretFileName,
-			},
-		})
-
-		endpoint := secrets[0].Annotations[deploy.CheEclipseOrgScmServerEndpoint]
-		if endpoint != "" {
-			mountEnv(deployment, []corev1.EnvVar{{
-				Name:  "CHE_INTEGRATION_GITHUB_SERVER__ENDPOINTS",
-				Value: endpoint,
-			}})
-		}
 	}
 
+	mountVolumes(deployment, secret, deploy.GitHubOAuthConfigMountPath)
+	mountEnv(deployment, "CHE_OAUTH2_GITHUB_CLIENTID__FILEPATH", deploy.GitHubOAuthConfigMountPath+"/"+deploy.GitHubOAuthConfigClientIdFileName)
+	mountEnv(deployment, "CHE_OAUTH2_GITHUB_CLIENTSECRET__FILEPATH", deploy.GitHubOAuthConfigMountPath+"/"+deploy.GitHubOAuthConfigClientSecretFileName)
+
+	oauthEndpoint := secret.Annotations[deploy.CheEclipseOrgScmServerEndpoint]
+	if oauthEndpoint != "" {
+		mountEnv(deployment, "CHE_INTEGRATION_GITHUB_OAUTH__ENDPOINT", oauthEndpoint)
+	}
 	return nil
 }
 
-func MountGitLabOAuthConfig(deployContext *deploy.DeployContext, deployment *appsv1.Deployment) error {
-	secrets, err := deploy.GetSecrets(deployContext, map[string]string{
-		deploy.KubernetesPartOfLabelKey:    deploy.CheEclipseOrg,
-		deploy.KubernetesComponentLabelKey: deploy.OAuthScmConfiguration,
-	}, map[string]string{
-		deploy.CheEclipseOrgOAuthScmServer: "gitlab",
-	})
-
-	if err != nil {
+func MountGitLabOAuthConfig(ctx *deploy.DeployContext, deployment *appsv1.Deployment) error {
+	secret, err := getOAuthConfig(ctx, "gitlab")
+	if secret == nil {
 		return err
-	} else if len(secrets) > 1 {
-		return errors.New("More than 1 GitLab OAuth configuration secrets found")
-	} else if len(secrets) == 1 {
-		mountSecret(deployment, &secrets[0], deploy.GitLabOAuthConfigMountPath)
-		mountEnv(deployment, []corev1.EnvVar{
-			{
-				Name:  "CHE_OAUTH_GITLAB_CLIENTID__FILEPATH",
-				Value: deploy.GitLabOAuthConfigMountPath + "/" + deploy.GitLabOAuthConfigClientIdFileName,
-			}, {
-				Name:  "CHE_OAUTH_GITLAB_CLIENTSECRET__FILEPATH",
-				Value: deploy.GitLabOAuthConfigMountPath + "/" + deploy.GitLabOAuthConfigClientSecretFileName,
-			},
-		})
-
-		endpoint := secrets[0].Annotations[deploy.CheEclipseOrgScmServerEndpoint]
-		if endpoint != "" {
-			mountEnv(deployment, []corev1.EnvVar{{
-				Name:  "CHE_INTEGRATION_GITLAB_SERVER__ENDPOINTS",
-				Value: endpoint,
-			}})
-		}
 	}
 
+	mountVolumes(deployment, secret, deploy.GitLabOAuthConfigMountPath)
+	mountEnv(deployment, "CHE_OAUTH2_GITLAB_CLIENTID__FILEPATH", deploy.GitLabOAuthConfigMountPath+"/"+deploy.GitLabOAuthConfigClientIdFileName)
+	mountEnv(deployment, "CHE_OAUTH2_GITLAB_CLIENTSECRET__FILEPATH", deploy.GitLabOAuthConfigMountPath+"/"+deploy.GitLabOAuthConfigClientSecretFileName)
+
+	oauthEndpoint := secret.Annotations[deploy.CheEclipseOrgScmServerEndpoint]
+	if oauthEndpoint != "" {
+		mountEnv(deployment, "CHE_INTEGRATION_GITLAB_OAUTH__ENDPOINT", oauthEndpoint)
+	}
 	return nil
 }
 
-func mountSecret(deployment *appsv1.Deployment, secret *corev1.Secret, mountPath string) {
+func mountVolumes(deployment *appsv1.Deployment, secret *corev1.Secret, mountPath string) {
 	container := &deployment.Spec.Template.Spec.Containers[0]
 	deployment.Spec.Template.Spec.Volumes = append(deployment.Spec.Template.Spec.Volumes,
 		corev1.Volume{
@@ -530,7 +472,10 @@ func mountSecret(deployment *appsv1.Deployment, secret *corev1.Secret, mountPath
 		})
 }
 
-func mountEnv(deployment *appsv1.Deployment, envVar []corev1.EnvVar) {
+func mountEnv(deployment *appsv1.Deployment, envName string, envValue string) {
 	container := &deployment.Spec.Template.Spec.Containers[0]
-	container.Env = append(container.Env, envVar...)
+	container.Env = append(container.Env, corev1.EnvVar{
+		Name:  envName,
+		Value: envValue,
+	})
 }
