@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2020-2020 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -25,7 +25,7 @@ const (
 	CheServiceName = "che-host"
 )
 
-var serviceDiffOpts = cmp.Options{
+var ServiceDefaultDiffOpts = cmp.Options{
 	cmpopts.IgnoreFields(corev1.Service{}, "TypeMeta", "ObjectMeta"),
 	cmp.Comparer(func(x, y corev1.ServiceSpec) bool {
 		return cmp.Equal(x.Ports, y.Ports, cmpopts.IgnoreFields(corev1.ServicePort{}, "TargetPort", "NodePort")) &&
@@ -45,7 +45,7 @@ func SyncServiceToCluster(
 }
 
 func SyncServiceSpecToCluster(deployContext *DeployContext, serviceSpec *corev1.Service) (bool, error) {
-	return Sync(deployContext, serviceSpec, serviceDiffOpts)
+	return Sync(deployContext, serviceSpec, ServiceDefaultDiffOpts)
 }
 
 func GetServiceSpec(
