@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2012-2019 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -479,21 +479,6 @@ func NewBoolPointer(value bool) *bool {
 	return &variable
 }
 
-func IsNativeUserModeEnabled(c *orgv1.CheCluster) bool {
-	// Native user mode is now available only on openshift
-	return IsOpenShift && c.Spec.Auth.NativeUserMode != nil && *c.Spec.Auth.NativeUserMode
-}
-
-// IsOAuthEnabled returns true when oAuth is enable for CheCluster resource, otherwise false.
-func IsOAuthEnabled(c *orgv1.CheCluster) bool {
-	return IsOpenShift && c.Spec.Auth.OpenShiftoAuth != nil && *c.Spec.Auth.OpenShiftoAuth
-}
-
-// IsInitialOpenShiftOAuthUserEnabled returns true when initial Openshift oAuth user is enabled for CheCluster resource, otherwise false.
-func IsInitialOpenShiftOAuthUserEnabled(c *orgv1.CheCluster) bool {
-	return c.Spec.Auth.InitialOpenShiftOAuthUser != nil && *c.Spec.Auth.InitialOpenShiftOAuthUser
-}
-
 // GetWorkspaceNamespaceDefault - returns workspace namespace default strategy, which points on the namespaces used for workspaces execution.
 func GetWorkspaceNamespaceDefault(cr *orgv1.CheCluster) string {
 	if cr.Spec.Server.CustomCheProperties != nil {
@@ -504,25 +489,12 @@ func GetWorkspaceNamespaceDefault(cr *orgv1.CheCluster) string {
 	}
 
 	workspaceNamespaceDefault := cr.Namespace
-	if IsOpenShift && IsOAuthEnabled(cr) {
+	if IsOpenShift && cr.IsOpenShiftOAuthEnabled() {
 		workspaceNamespaceDefault = "<username>-" + cr.Spec.Server.CheFlavor
 	}
 	return GetValue(cr.Spec.Server.WorkspaceNamespaceDefault, workspaceNamespaceDefault)
 }
 
-// GetCheServerCustomCheProperty - returns value of che-server's custom property.
-func GetCheServerCustomCheProperty(cr *orgv1.CheCluster, key string) string {
-	if cr.Spec.Server.CustomCheProperties != nil {
-		return cr.Spec.Server.CustomCheProperties[key]
-	}
-	return ""
-}
-
-// IsDeleteOAuthInitialUser - returns true when initial Openshfit oAuth user must be deleted.
-func IsDeleteOAuthInitialUser(cr *orgv1.CheCluster) bool {
-	return cr.Spec.Auth.InitialOpenShiftOAuthUser != nil && !*cr.Spec.Auth.InitialOpenShiftOAuthUser && cr.Status.OpenShiftOAuthUserCredentialsSecret != ""
-}
-
 func GetResourceQuantity(value string, defaultValue string) resource.Quantity {
 	if value != "" {
 		return resource.MustParse(value)
